Comment class

Comment information

Implementers

Constructors

Comment({String? descriptor, String? language, String? text})
Create a Comment
const

Properties

descriptor String?
Optional descriptor/type
final
hashCode int
The hash code for this object.
no setterinherited
language String?
Language code
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String?
Comment text
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited